@@ -206,13 +206,16 @@ def _read_parameters(  # noqa: WPS231
         if annotation is None:
             _warn(docstring, line_number, f"No type or annotation for parameter '{name}'")
 
-        if warn_unknown_params and docstring.parent is not None:
-            if name not in docstring.parent.parameters:  # type: ignore[attr-defined]
-                _warn(
-                    docstring,
-                    line_number,
-                    f"Parameter '{name}' does not appear in the parent signature",
-                )
+        if warn_unknown_params:
+            with suppress(AttributeError):  # for parameters sections in objects without parameters
+                params = docstring.parent.parameters  # type: ignore[union-attr]
+                if name not in params:
+                    message = f"Parameter '{name}' does not appear in the function signature"
+                    for starred_name in (f"*{name}", f"**{name}"):
+                        if starred_name in params:
+                            message += f". Did you mean '{starred_name}'?"
+                            break
+                    _warn(docstring, line_number, message)
 
         parameters.append(DocstringParameter(name=name, value=default, annotation=annotation, description=description))
 
@@ -360,7 +363,12 @@ def _read_returns_section(  # noqa: WPS231
         else:
             # try to retrieve the annotation from the docstring parent
             with suppress(AttributeError, KeyError, ValueError):
-                annotation = docstring.parent.returns  # type: ignore[union-attr]
+                if docstring.parent.is_function:  # type: ignore[union-attr]
+                    annotation = docstring.parent.returns  # type: ignore[union-attr]
+                elif docstring.parent.is_attribute:  # type: ignore[union-attr]
+                    annotation = docstring.parent.annotation  # type: ignore[union-attr]
+                else:
+                    raise ValueError
                 if len(block) > 1:
                     if annotation.is_tuple:
                         annotation = annotation.tuple_item(index)
