@@ -4,15 +4,15 @@ import sys
 
 import pytest
 
-from griffe import cli
+from griffe import cli  # type: ignore[attr-defined]
 
 
 def test_main():
     """Basic CLI test."""
     if sys.platform == "win32":
-        assert cli.main(["griffe", "-s", "src", "-oNUL"]) == 0
+        assert cli.main(["dump", "griffe", "-s", "src", "-oNUL"]) == 0
     else:
-        assert cli.main(["griffe", "-s", "src", "-o/dev/null"]) == 0
+        assert cli.main(["dump", "griffe", "-s", "src", "-o/dev/null"]) == 0
 
 
 def test_show_help(capsys):
